==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/ReplyStateAnnotationType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p135820_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:p874817_="https://jakarta.ee/xml/ns/jaxb" xmlns:p942898_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;An annotation, that provides a "reply state" for a selected annotation.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for ReplyStateAnnotationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ReplyStateAnnotationType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseReplyType">
 *       <attribute name="replyState" type="{http://schema.webpdf.de/1.0/operation}ReplyState" default="none" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ReplyStateAnnotationType")
public class ReplyStateAnnotationType
    extends BaseReplyType
{

    @XmlAttribute(name = "replyState")
    protected ReplyState replyState;

    /**
     * Gets the value of the replyState property.
     * 
     * @return
     *     possible object is
     *     {@link ReplyState }
     *     
     */
    public ReplyState getReplyState() {
        if (replyState == null) {
            return ReplyState.NONE;
        } else {
            return replyState;
        }
    }

    /**
     * Sets the value of the replyState property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReplyState }
     *     
     */
    public void setReplyState(ReplyState value) {
        this.replyState = value;
    }

    public boolean isSetReplyState() {
        return (this.replyState!= null);
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ReplyStateAnnotationType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p105796_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p913707_="https://jakarta.ee/xml/ns/jaxb" xmlns:p931759_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;An annotation, that provides a "reply state" for a selected annotation.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for ReplyStateAnnotationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ReplyStateAnnotationType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseReplyType">
 *       <attribute name="replyState" type="{http://schema.webpdf.de/1.0/operation}ReplyState" default="none" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ReplyStateAnnotationType")
public class ReplyStateAnnotationType
    extends BaseReplyType
{

    @XmlAttribute(name = "replyState")
    protected ReplyState replyState;

    /**
     * Gets the value of the replyState property.
     * 
     * @return
     *     possible object is
     *     {@link ReplyState }
     *     
     */
    public ReplyState getReplyState() {
        if (replyState == null) {
            return ReplyState.NONE;
        } else {
            return replyState;
        }
    }

    /**
     * Sets the value of the replyState property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReplyState }
     *     
     */
    public void setReplyState(ReplyState value) {
        this.replyState = value;
    }

    public boolean isSetReplyState() {
        return (this.replyState!= null);
    }

}
